import type { Matrix, Vector } from "./types";
/**
 * Returns a matrix (multi-dimensional array) with your desired dimensions and values.
 *
 * If a number is passed as the `dimensions` parameter, a matrix with that number of dimensions
 * is returned. If an array of numbers is passed, the returned matrix have those exact dimensions.
 *
 * @param dimensions    The desired dimensions of the matrix. A number or array of numbers.
 * @param initialValues The initial value for each point in the matrix. Can also take a callback function to fill the matrix dynamically. Defaults to `null`.
 *
 * @example
 * const twoDArray = makeMatrix(2); // A 2D array
 * const threeXThreeXTwoArray = makeMatrix([3, 3, 2]); // A 3x3x2 array
 * const twoDNumberArray = makeMatrix([3, 5], 0); // A 3x5 array containing 0
 * const twoDRandomNumberArray = makeMatrix([1, 4], () => Math.random()); // A 1x4 array containing random numbers
 * const twoDVectorArray = makeMatrix([3, 3], vector => vector.join()); // A 3x3 array containing each point's co-ordinate as a string
 */
declare const makeMatrix: <D extends number, T>(dimensions: D | Vector<D>, initialValues?: T | ((vector: Vector<D>) => T) | null) => Matrix<D, T>;
export default makeMatrix;
export { makeMatrix, type Matrix };
